#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-hlint-plugin
version:              2.3.0.0
visibility:           public
id:                   hls-hlint-plugin-2.3.0.0-5plFLHs0GxgEwswwb0vt75
key:                  hls-hlint-plugin-2.3.0.0-5plFLHs0GxgEwswwb0vt75
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           atreyu.bbb@gmail.com
author:               The Haskell IDE Team
synopsis:             Hlint integration plugin with Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  545cc81a8439999ee6356aaed8ec0b4e
exposed:              True
exposed-modules:      Ide.Plugin.Hlint
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hls-hlint-plugin-2.3.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hls-hlint-plugin-2.3.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hls-hlint-plugin-2.3.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-hlint-plugin
hs-libraries:         HShls-hlint-plugin-2.3.0.0-5plFLHs0GxgEwswwb0vt75
depends:
    Diff-0.5-FZf73yFK5p0KQrOhLflBbT
    aeson-2.2.1.0-Def4REbZAAu5MJxZQtCFDo
    apply-refact-0.14.0.0-LEboi9dbcL59D1Ym5OYaGO base-4.18.2.1
    binary-0.8.9.1 bytestring-0.11.5.3 containers-0.6.7
    data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz deepseq-1.4.8.1
    directory-1.3.8.5 extra-1.7.16-7J4flVDuVp79ZQl3ULvjo5
    filepath-1.4.300.1 ghc-9.6.6 ghc-boot-9.6.6
    ghc-exactprint-1.7.1.0-EjrTaLmfueE8YeSqB1isRU
    ghc-lib-parser-ex-9.6.0.2-FSOeeIh5SuBMsWC0ukVSo
    ghcide-2.3.0.0-Lt4QFZ7pYbu7eGKlzEamHk
    hashable-1.4.7.0-3mscVqjFvnNHNJmw9rQ9m6
    hlint-3.6.1-BOaA3kD8B2YDRMHsKyzEpF
    hls-plugin-api-2.3.0.0-9Ew4wivxLgiCEnvMUZLJta
    lens-5.3.4-59xiJiOdHtvHZvlFC0zvFo
    lsp-2.2.0.0-3kjUeEaFVQXJXrrpQSwskJ mtl-2.3.1
    refact-0.3.0.2-FJtsqxURVxtCj2G2lOYVeD
    regex-tdfa-1.3.2.5-1f9YjGvAf24EdoqRc3t0wn stm-2.5.1.0
    temporary-1.3-EZyCN0IpTQNJIMCpUwiknJ text-2.0.2
    transformers-0.6.1.0
    unordered-containers-0.2.20.1-CeHDQtVso2t69dwLJnxrjh

haddock-interfaces:
    /usr/share/doc/haskell-hls-hlint-plugin/html/hls-hlint-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-hlint-plugin/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

